@@ -112,12 +112,14 @@ class StateRecord(NymmsDataType, StateMixin):
     required_fields = ['state', 'state_type']
 
     def __init__(self, object_id, last_update=None, last_state_change=None,
-                 state=None, state_type=None, origin=None):
+                 state=None, state_type=None, quiet_timestamp=0,
+                 origin=None):
         super(StateRecord, self).__init__(object_id=object_id, origin=origin)
         self.last_update = last_update
         self.last_state_change = last_state_change
         self.state = state
         self.state_type = state_type
+        self.quiet_timestamp = quiet_timestamp
         self._cleaned = {}
 
     def validate_last_update(self):
